@@ -7,7 +7,7 @@ A powerful multi-modal AI Agent system with modern architecture.
 from .core import Session, Agent, HTTPAgentServer
 from .schemas import Message, ToolCall
 from .db import MessageDB
-from .utils import function_tool, MCPTool, upload_image
+from .utils import function_tool
 from .tools import web_search, draw_image
 from .multi import Swarm, Workflow
 from .__version__ import __version__
@@ -25,9 +25,7 @@ __all__ = [
     
     # Utilities
     "function_tool",
-    "MCPTool", 
-    "upload_image",
-    
+
     # Built-in tools
     "web_search",
     "draw_image",
