@@ -7,6 +7,9 @@ from fastapi import FastAPI, HTTPException
 from pydantic import BaseModel
 import json
 from fastapi.responses import StreamingResponse
+from dotenv import load_dotenv
+
+load_dotenv(override=True)
 
 from ..core.base import BaseAgentRunner
 from ..core.session import Session
@@ -103,7 +106,11 @@ class HTTPAgentServer(BaseAgentRunner):
                                 yield "data: [DONE]\n\n"
                             else:
                                 # Fallback when no generator is returned
-                                yield f"data: {json.dumps({'message': str(response)})}\n\n"
+                                # Handle structured output properly
+                                if hasattr(response, 'model_dump'):  # Pydantic BaseModel
+                                    yield f"data: {json.dumps({'message': response.model_dump()})}\n\n"
+                                else:  # String response
+                                    yield f"data: {json.dumps({'message': str(response)})}\n\n"
                                 yield "data: [DONE]\n\n"
                         except Exception as e:
                             # Stream error as SSE, client can handle gracefully
@@ -118,7 +125,11 @@ class HTTPAgentServer(BaseAgentRunner):
                     image_source=input_data.image_source
                 )
                 
-                return {"reply": str(response)}
+                # Handle different response types properly
+                if hasattr(response, 'model_dump'):  # Pydantic BaseModel
+                    return {"reply": response.model_dump()}
+                else:  # String response
+                    return {"reply": str(response)}
                 
             except Exception as e:
                 raise HTTPException(status_code=500, detail=f"Agent processing error: {str(e)}")
